@@ -46,7 +46,7 @@ def import_spydercustomize():
 
     # Import our customizations
     site.addsitedir(customize_dir)
-    import spydercustomize
+    import spydercustomize  # noqa
 
     # Remove our customize path from sys.path
     try:
@@ -109,9 +109,18 @@ def kernel_config():
     # Spyder, to avoid deleting the sys module if users want to import
     # it through them.
     # See spyder-ide/spyder#15788
-    clear_argv = "import sys;sys.argv = [''];del sys"
+    clear_argv = "import sys; sys.argv = ['']; del sys"
     spy_cfg.IPKernelApp.exec_lines = [clear_argv]
 
+    # Set our runfile in builtins here to prevent other packages shadowing it.
+    # This started to be a problem since IPykernel 6.3.0.
+    if not PY2:
+        spy_cfg.IPKernelApp.exec_lines.append(
+            "import builtins; "
+            "builtins.runfile = builtins.spyder_runfile; "
+            "del builtins.spyder_runfile; del builtins"
+        )
+
     # Run lines of code at startup
     run_lines_o = os.environ.get('SPY_RUN_LINES_O')
     if run_lines_o is not None:
