@@ -71,7 +71,7 @@ def make_app_bundle(dist_dir, make_lite=False):
     docutils :
         [Errno 20] Not a directory: '<path>/Resources/lib/python39.zip/
         docutils/writers/latex2e/docutils.sty'
-    ipython :
+    IPython :
         [IPKernelApp] WARNING | Could not copy README_STARTUP to startup dir.
         Source file
         <path>/Resources/lib/python38.zip/IPython/core/profile/README_STARTUP
@@ -97,18 +97,20 @@ def make_app_bundle(dist_dir, make_lite=False):
         Note: only applicable to not-Lite build
     pygments :
         ModuleNotFoundError: No module named 'pygments.formatters.latex'
-    pyls :
-        <path>/Contents/MacOS/python: No module named pyls
+    pylint :
+        <path>/Contents/MacOS/python: No module named pylint.__main__
+    pylsp :
+        <path>/Contents/MacOS/python: No module named pylsp
         Note: still occurs in alias mode
-    pyls_black :
-        Mandatory: pyls_black >=0.4.6 : None (NOK)
+    pylsp_black :
+        Mandatory: python-pyls-black >=1.0.0 : None (NOK)
     pyls_spyder :
         Mandatory: pyls_spyder >=0.1.1 : None (NOK)
     qtawesome :
         NotADirectoryError: [Errno 20] Not a directory: '<path>/Resourses/lib/
         python38.zip/qtawesome/fonts/fontawesome4.7-webfont.ttf'
     setuptools :
-        Mandatory: setuptools >=39.0.0 : None (NOK)
+        Mandatory: setuptools >=49.6.0 : None (NOK)
     sphinx :
         No module named 'sphinx.builders.changes'
     spyder :
@@ -143,16 +145,19 @@ def make_app_bundle(dist_dir, make_lite=False):
     build_type = 'lite' if make_lite else 'full'
     logger.info('Creating %s app bundle...', build_type)
 
-    PACKAGES = ['alabaster', 'astroid', 'docutils', 'blib2to3', 'IPython',
-                'jedi', 'jinja2', 'keyring', 'parso', 'pygments', 'pyls',
-                'pyls_black', 'pyls_spyder', 'qtawesome', 'setuptools',
-                'sphinx', 'spyder', 'spyder_kernels', 'textdistance',
+    PACKAGES = ['alabaster', 'astroid', 'blib2to3', 'docutils', 'IPython',
+                'jedi', 'jinja2', 'keyring', 'parso', 'pygments', 'pylint',
+                'pylsp', 'pylsp_black', 'pyls_spyder', 'qtawesome',
+                'setuptools', 'sphinx', 'spyder', 'spyder_kernels',
+                'textdistance',
                 ]
     INCLUDES = ['_sitebuiltins',  # required for IPython help()
                 # required for sphinx
                 'sphinxcontrib.applehelp', 'sphinxcontrib.devhelp',
                 'sphinxcontrib.htmlhelp', 'sphinxcontrib.jsmath',
-                'sphinxcontrib.qthelp', 'sphinxcontrib.serializinghtml']
+                'sphinxcontrib.qthelp', 'sphinxcontrib.serializinghtml',
+                'platformdirs.macos',  # required for platformdirs
+                ]
     EXCLUDES = []
     EXCLUDE_EGG = ['py2app']
 
