@@ -72,6 +72,14 @@ class HelpWidgetMainToolbarSections:
     Main = 'main_section'
 
 
+class HelpWidgetToolbarItems:
+    SourceLabel = 'source_label'
+    SourceCombo = 'source_combo'
+    ObjectLabel = 'object_label'
+    ObjectCombo = 'object_combo'
+    ObjectEdit = 'object_edit'
+
+
 # --- Widgets
 # ----------------------------------------------------------------------------
 class ObjectComboBox(EditableComboBox):
@@ -81,12 +89,15 @@ class ObjectComboBox(EditableComboBox):
     # Signals
     valid = Signal(bool, bool)
 
-    def __init__(self, parent):
+    def __init__(self, parent, id_=None):
         EditableComboBox.__init__(self, parent)
         self.help = parent
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         self.tips = {True: '', False: ''}
 
+        if id_ is not None:
+            self.ID = id_
+
     def is_valid(self, qstr=None):
         """Return True if string is valid"""
         if not self.help.source_is_console():
@@ -284,7 +295,7 @@ class HelpWidget(PluginMainWidget):
         self._last_editor_doc = None
         self._last_console_cb = None
         self._last_editor_cb = None
-        self.css_path = self.get_conf('css_path')
+        self.css_path = self.get_conf('css_path', CSS_PATH, 'appearance')
         self.no_docs = _("No documentation available")
         self.docstring = True  # TODO: What is this used for?
 
@@ -298,11 +309,21 @@ class HelpWidget(PluginMainWidget):
         self.internal_shell = None
         self.plain_text = PlainText(self)
         self.rich_text = RichText(self)
+
         self.source_label = QLabel(_("Source"))
+        self.source_label.ID = HelpWidgetToolbarItems.SourceLabel
+
         self.source_combo = QComboBox(self)
+        self.source_combo.ID = HelpWidgetToolbarItems.SourceCombo
+
         self.object_label = QLabel(_("Object"))
-        self.object_combo = ObjectComboBox(self)
+        self.object_label.ID = HelpWidgetToolbarItems.ObjectLabel
+
+        self.object_combo = ObjectComboBox(
+            self, HelpWidgetToolbarItems.ObjectCombo)
+
         self.object_edit = QLineEdit(self)
+        self.object_edit.ID = HelpWidgetToolbarItems.ObjectEdit
 
         # Setup
         self.object_edit.setReadOnly(True)
